## Generated by PyCDP
The modules of this package were generated by [pycdp][1], do not modify their contents because the
changes will be overwritten in next generations.

[1]: https://github.com/HMaker/python-chrome-devtools-protocol
